@@ -69,6 +69,13 @@ class CellActions(Actions):
         """Returns string quoted code """
 
         old_code = self.grid.code_array(key)
+        try:
+            old_code = old_code.rstrip()
+
+        except AttributeError:
+            # Old code is None --> There is no code to quote
+            return
+
         if old_code and old_code[0] + old_code[-1] not in ('""', "''") and \
             '"' not in old_code:
             self.set_code(key, '"' + old_code + '"', mark_unredo=mark_unredo)
@@ -348,12 +355,17 @@ class CellActions(Actions):
         selection = Selection([], [], [], [], [cursor[:2]])
         self.set_attr("frozen", not frozen, selection=selection)
 
+    def change_locked_attr(self):
+        """Changes locked state of cell if there is no selection"""
+
+        raise NotImplementedError
+
     def unmerge(self, unmerge_area, tab):
         """Unmerges all cells in unmerge_area"""
 
         top, left, bottom, right = unmerge_area
         selection = Selection([(top, left)], [(bottom, right)], [], [], [])
-        attr = {"merge_area": None}
+        attr = {"merge_area": None, "locked": False}
 
         self._set_cell_attr(selection, tab, attr)
 
@@ -362,10 +374,15 @@ class CellActions(Actions):
 
         top, left, bottom, right = merge_area
         selection = Selection([(top, left)], [(bottom, right)], [], [], [])
-        attr = {"merge_area": merge_area}
+        attr = {"merge_area": merge_area, "locked": True}
 
         self._set_cell_attr(selection, tab, attr)
 
+        tl_selection = Selection([], [], [], [], [(top, left)])
+        attr = {"locked": False}
+
+        self._set_cell_attr(tl_selection, tab, attr)
+
     def merge_selected_cells(self, selection):
         """Merges or unmerges cells that are in the selection bounding box
 
@@ -401,6 +418,7 @@ class CellActions(Actions):
         "fontstyle": [wx.NORMAL, wx.ITALIC],
         "underline": [False, True],
         "strikethrough": [False, True],
+        "locked": [False, True],
         "vertical_align": ["top", "middle", "bottom"],
         "justification": ["left", "center", "right"],
         "frozen": [True, False],
@@ -460,6 +478,13 @@ class CellActions(Actions):
             # Default next value
             return self.attr_toggle_values[attr_key][1]
 
+    def refresh_frozen_cell(self, key):
+        """Refreshes a frozen cell"""
+
+        code = self.grid.code_array(key)
+        result = self.grid.code_array._eval_cell(key, code)
+        self.grid.code_array.frozen_cache[repr(key)] = result
+
     def refresh_selected_frozen_cells(self, selection=None):
         """Refreshes content of frozen cells that are currently selected
 
@@ -482,6 +507,8 @@ class CellActions(Actions):
 
         cell_attributes = self.grid.code_array.cell_attributes
 
+        refreshed_keys = []
+
         for attr_selection, tab, attr_dict in cell_attributes:
             if tab == self.grid.actions.cursor[2] and \
                "frozen" in attr_dict and attr_dict["frozen"]:
@@ -489,8 +516,9 @@ class CellActions(Actions):
                 skey = attr_selection.cells[0]
                 if skey in selection:
                     key = tuple(list(skey) + [tab])
-                    code = self.grid.code_array(key)
-                    result = self.grid.code_array._eval_cell(key, code)
-                    self.grid.code_array.frozen_cache[repr(key)] = result
+                    if key not in refreshed_keys and \
+                       cell_attributes[key]["frozen"]:
+                        self.refresh_frozen_cell(key)
+                        refreshed_keys.append(key)
 
         cell_attributes._attr_cache.clear()
