@@ -614,7 +614,10 @@ class MainWindowEventHandlers(EventMixin):
                            shape=shape)
 
         if is_gtk():
-            wx.Yield()
+            try:
+                wx.Yield()
+            except:
+                pass
 
         self.main_window.grid.actions.change_grid_shape(shape)
 
@@ -629,7 +632,10 @@ class MainWindowEventHandlers(EventMixin):
         self.main_window.grid.ForceRefresh()
 
         if is_gtk():
-            wx.Yield()
+            try:
+                wx.Yield()
+            except:
+                pass
 
         # Mark content as unchanged
         try:
@@ -658,17 +664,21 @@ class MainWindowEventHandlers(EventMixin):
         # Get filepath from user
 
         try:
+            # Do not offer xls if xlrd is missing
             import xlrd
             wildcard = \
                 _("Pyspread file") + " (*.pys)|*.pys|" + \
+                _("Uncompressed pyspread file") + " (*.pysu)|*.pysu|" + \
                 _("Excel file") + " (*.xls)|*.xls|" + \
                 _("All files") + " (*.*)|*.*"
+            filetypes = ["pys", "pysu", "xls", "pys"]
 
         except ImportError:
             wildcard = \
                 _("Pyspread file") + " (*.pys)|*.pys|" + \
+                _("Uncompressed pyspread file") + " (*.pysu)|*.pysu|" + \
                 _("All files") + " (*.*)|*.*"
-            xlrd = None
+            filetypes = ["pys", "pysu", "pys"]
 
         message = _("Choose file to open.")
         style = wx.OPEN
@@ -679,7 +689,7 @@ class MainWindowEventHandlers(EventMixin):
         if filepath is None:
             return
 
-        filetype = "pys" if xlrd is None or filterindex != 1 else "xls"
+        filetype = filetypes[filterindex]
 
         # Change the main window filepath state
 
@@ -699,7 +709,10 @@ class MainWindowEventHandlers(EventMixin):
         self.main_window.grid.ForceRefresh()
 
         if is_gtk():
-            wx.Yield()
+            try:
+                wx.Yield()
+            except:
+                pass
 
         # Mark content as unchanged
         try:
@@ -712,6 +725,12 @@ class MainWindowEventHandlers(EventMixin):
     def OnSave(self, event):
         """File save event handler"""
 
+        try:
+            filetype = event.attr["filetype"]
+
+        except (KeyError, AttributeError):
+            filetype = "pys"
+
         # If there is no filepath then jump to save as
 
         if self.main_window.filepath is None:
@@ -723,7 +742,8 @@ class MainWindowEventHandlers(EventMixin):
 
         post_command_event(self.main_window,
                            self.main_window.GridActionSaveMsg,
-                           attr={"filepath": self.main_window.filepath})
+                           attr={"filepath": self.main_window.filepath,
+                                 "filetype": filetype})
 
         # Display file save in status bar
 
@@ -737,9 +757,22 @@ class MainWindowEventHandlers(EventMixin):
 
         # Get filepath from user
 
-        wildcard = \
-            _("Pyspread file") + " (*.pys)|*.pys|" + \
-            _("All files") + " (*.*)|*.*"
+        try:
+            import xlwt
+            wildcard = \
+                _("Pyspread file") + " (*.pys)|*.pys|" + \
+                _("Uncompressed pyspread file") + " (*.pysu)|*.pysu|" + \
+                _("Excel file") + _(" (experimental)") + " (*.xls)|*.xls|" + \
+                _("All files") + " (*.*)|*.*"
+            filetypes = ["pys", "pysu", "xls", "pys"]
+
+        except ImportError:
+            wildcard = \
+                _("Pyspread file") + " (*.pys)|*.pys|" + \
+                _("Uncompressed pyspread file") + " (*.pysu)|*.pysu|" + \
+                _("All files") + " (*.*)|*.*"
+            filetypes = ["pys", "pysu", "pys"]
+
         message = _("Choose filename for saving.")
         style = wx.SAVE
         filepath, filterindex = \
@@ -749,6 +782,8 @@ class MainWindowEventHandlers(EventMixin):
         if filepath is None:
             return 0
 
+        filetype = filetypes[filterindex]
+
         # Look if path is already present
         if os.path.exists(filepath):
             if not os.path.isfile(filepath):
@@ -787,7 +822,8 @@ class MainWindowEventHandlers(EventMixin):
                            text=title_text)
 
         # Now jump to save
-        post_command_event(self.main_window, self.main_window.SaveMsg)
+        post_command_event(self.main_window, self.main_window.SaveMsg,
+                           attr={"filetype": filetype})
 
     def OnImport(self, event):
         """File import event handler"""
@@ -1120,7 +1156,10 @@ class MainWindowEventHandlers(EventMixin):
                                style=font.GetStyleString())
 
             if is_gtk():
-                wx.Yield()
+                try:
+                    wx.Yield()
+                except:
+                    pass
 
             self.main_window.grid.update_attribute_toolbar()
 
@@ -1256,6 +1295,8 @@ class MainWindowEventHandlers(EventMixin):
     def OnPythonTutorial(self, event):
         """Python tutorial launch event handler"""
 
+        # Doas not work any more
+
         self.main_window.actions.launch_help("Python tutorial",
                                              get_python_tutorial_path())
 
