@@ -164,6 +164,10 @@ class MainToolbar(ToolbarBase):
             ["T", self.CopyResultMsg, "EditCopyRes", _("Copy Results")],
             ["T", self.PasteMsg, "EditPaste", _("Paste")],
             ["S"],
+            ["T", self.SortAscendingMsg, "SortAscending", _("Sort ascending")],
+            ["T", self.SortDescendingMsg, "SortDescending",
+             _("Sort descending")],
+            ["S"],
             ["T", self.PrintMsg, "FilePrint", _("Print")],
         ]
 
@@ -337,7 +341,6 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
         ("RightBorders",     (0, 0, 0, 1, 1, 1)),
         ("TopBorders",       (1, 0, 0, 0, 1, 1)),
         ("BottomBorders",    (0, 1, 0, 0, 1, 1)),
-        ##("InsideBorders",    (1, 1, 1, 1, 1, 0)),
         ("OutsideBorders",   (1, 1, 1, 1, 0, 1)),
         ("TopBottomBorders", (1, 1, 0, 0, 0, 1)),
     ]
@@ -348,7 +351,6 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
         "RightBorders":     ("right"),
         "TopBorders":       ("top"),
         "BottomBorders":    ("bottom"),
-        ##"InsideBorders":    ("inner"),
         "OutsideBorders":   ("top", "bottom", "left", "right"),
         "TopBottomBorders": ("top", "bottom"),
     }
@@ -387,6 +389,9 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
         self.font_choice_combo = \
             _widgets.FontChoiceCombobox(self, choices=self.fonts,
                                         style=wx.CB_READONLY, size=(125, -1))
+
+        self.font_choice_combo.SetToolTipString(_(u"Text font"))
+
         self.AddControl(self.font_choice_combo)
 
         self.Bind(wx.EVT_COMBOBOX, self.OnTextFont, self.font_choice_combo)
@@ -401,6 +406,9 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
             wx.ComboBox(self, -1, value=font_size, size=(60, -1),
                         choices=map(unicode, self.std_font_sizes),
                         style=wx.CB_DROPDOWN | wx.TE_PROCESS_ENTER)
+
+        self.font_size_combo.SetToolTipString(_(u"Text size\n(points)"))
+
         self.AddControl(self.font_size_combo)
         self.Bind(wx.EVT_COMBOBOX, self.OnTextSize, self.font_size_combo)
         self.Bind(wx.EVT_TEXT_ENTER, self.OnTextSize, self.font_size_combo)
@@ -417,6 +425,7 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
             (wx.FONTFLAG_STRIKETHROUGH, "OnStrikethrough",
                 "FormatTextStrikethrough", _("Strikethrough")),
             (wx.FONTFLAG_MASK, "OnFreeze", "Freeze", _("Freeze")),
+            (wx.FONTFLAG_NOT_ANTIALIASED, "OnLock", "Lock", _("Lock cell")),
         ]
 
         for __id, method, iconname, helpstring in font_face_buttons:
@@ -431,6 +440,7 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
         iconnames = ["JustifyLeft", "JustifyCenter", "JustifyRight"]
         bmplist = [icons[iconname] for iconname in iconnames]
         self.justify_tb = _widgets.BitmapToggleButton(self, bmplist)
+        self.justify_tb.SetToolTipString(_(u"Justification"))
         self.Bind(wx.EVT_BUTTON, self.OnJustification, self.justify_tb)
         self.AddControl(self.justify_tb)
 
@@ -441,6 +451,7 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
         bmplist = [icons[iconname] for iconname in iconnames]
 
         self.alignment_tb = _widgets.BitmapToggleButton(self, bmplist)
+        self.alignment_tb.SetToolTipString(_(u"Alignment"))
         self.Bind(wx.EVT_BUTTON, self.OnAlignment, self.alignment_tb)
         self.AddControl(self.alignment_tb)
 
@@ -452,6 +463,9 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
             _widgets.BorderEditChoice(self, choices=choices,
                                       style=wx.CB_READONLY, size=(50, -1))
 
+        self.borderchoice_combo.SetToolTipString(
+            _(u"Choose borders for which attributes are changed"))
+
         self.borderstate = self.border_toggles[0][0]
 
         self.AddControl(self.borderchoice_combo)
@@ -469,6 +483,7 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
             _widgets.PenWidthComboBox(self, choices=choices,
                                       style=wx.CB_READONLY, size=(50, -1))
 
+        self.pen_width_combo.SetToolTipString(_(u"Border width"))
         self.AddControl(self.pen_width_combo)
         self.Bind(wx.EVT_COMBOBOX, self.OnLineWidth, self.pen_width_combo)
 
@@ -495,6 +510,10 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
             csel.ColourSelect(self, -1, "A", (0, 0, 0),
                               size=button_size, style=button_style)
 
+        self.linecolor_choice.SetToolTipString(_(u"Border line color"))
+        self.bgcolor_choice.SetToolTipString(_(u"Cell background"))
+        self.textcolor_choice.SetToolTipString(_(u"Text color"))
+
         self.AddControl(self.linecolor_choice)
         self.AddControl(self.bgcolor_choice)
         self.AddControl(self.textcolor_choice)
@@ -521,6 +540,7 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
 
         # For compatibility with toggle buttons
         self.rotation_spinctrl.GetToolState = lambda x: None
+        self.rotation_spinctrl.SetToolTipString(_(u"Cell text rotation"))
 
         self.AddControl(self.rotation_spinctrl)
 
@@ -605,6 +625,19 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
 
         self.ToggleTool(wx.FONTFLAG_MASK, toggle_state)
 
+    def _update_lockedcell(self, locked):
+        """Updates frozen cell widget
+
+        Parameters
+        ----------
+
+        locked: Bool or string
+        \tUntoggled iif False
+
+        """
+
+        self.ToggleTool(wx.FONTFLAG_NOT_ANTIALIASED, locked)
+
     def _update_underline(self, underlined):
         """Updates underline widget
 
@@ -727,6 +760,7 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
         self._update_font_weight(attributes["fontweight"])
         self._update_font_style(attributes["fontstyle"])
         self._update_frozencell(attributes["frozen"])
+        self._update_lockedcell(attributes["locked"])
         self._update_underline(attributes["underline"])
         self._update_strikethrough(attributes["strikethrough"])
         self._update_justification(attributes["justification"])
@@ -810,25 +844,30 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
         post_command_event(self, self.FontBoldMsg)
 
     def OnItalics(self, event):
-        """Bold toggle button event handler"""
+        """Italics toggle button event handler"""
 
         post_command_event(self, self.FontItalicsMsg)
 
     def OnUnderline(self, event):
-        """Bold toggle button event handler"""
+        """Underline toggle button event handler"""
 
         post_command_event(self, self.FontUnderlineMsg)
 
     def OnStrikethrough(self, event):
-        """Bold toggle button event handler"""
+        """Strikethrough toggle button event handler"""
 
         post_command_event(self, self.FontStrikethroughMsg)
 
     def OnFreeze(self, event):
-        """Bold toggle button event handler"""
+        """Frozen toggle button event handler"""
 
         post_command_event(self, self.FrozenMsg)
 
+    def OnLock(self, event):
+        """Lock toggle button event handler"""
+
+        post_command_event(self, self.LockMsg)
+
     def OnJustification(self, event):
         """Justification toggle button event handler"""
 
@@ -851,4 +890,4 @@ class AttributesToolbar(aui.AuiToolBar, EventMixin):
 
         post_command_event(self, self.TextRotationMsg, angle=angle)
 
-# end of class AttributesToolbar
\ No newline at end of file
+# end of class AttributesToolbar
