@@ -40,9 +40,15 @@ Provides:
 
 """
 
+import __builtin__
 import keyword
 from copy import copy
 
+try:
+    import jedi
+except ImportError:
+    jedi = None
+
 import wx
 import wx.grid
 import wx.combo
@@ -50,6 +56,7 @@ import wx.stc as stc
 from wx.lib.intctrl import IntCtrl, EVT_INT
 
 import src.lib.i18n as i18n
+from src.lib.parsers import common_start
 from src.config import config
 from src.sysvars import get_default_font, is_gtk
 
@@ -62,6 +69,9 @@ from icons import icons
 #use ugettext instead of getttext to avoid unicode errors
 _ = i18n.language.ugettext
 
+# Maximum tooltip string length
+MAX_TOOLTIP_LENGTH = 1000
+
 
 class PythonSTC(stc.StyledTextCtrl):
     """Editor that highlights Python source code.
@@ -672,6 +682,7 @@ class EntryLineToolbarPanel(wx.Panel):
     def __init__(self, parent, *args, **kwargs):
         wx.Panel.__init__(self, parent, *args, **kwargs)
 
+        self.parent = parent
         # Panel with EntryLine and button
         self.entry_line_panel = EntryLinePanel(self, parent, -1)
 
@@ -763,7 +774,8 @@ class EntryLine(wx.TextCtrl, EntryLineEventMixin, GridCellEventMixin,
     """"The line for entering cell code"""
 
     def __init__(self, parent, main_window, id=-1, *args, **kwargs):
-        kwargs["style"] = wx.TE_PROCESS_ENTER | wx.TE_MULTILINE
+        kwargs["style"] = wx.TE_PROCESS_ENTER | wx.TE_MULTILINE | \
+            wx.TE_PROCESS_TAB
         wx.TextCtrl.__init__(self, parent, id, *args, **kwargs)
 
         self.SetSize((700, 25))
@@ -780,6 +792,7 @@ class EntryLine(wx.TextCtrl, EntryLineEventMixin, GridCellEventMixin,
 
         main_window.Bind(self.EVT_ENTRYLINE_MSG, self.OnContentChange)
         main_window.Bind(self.EVT_CMD_SELECTION, self.OnGridSelection)
+        main_window.Bind(self.EVT_ENTRYLINE_LOCK, self.OnLock)
 
         self.SetToolTip(wx.ToolTip(_("Enter Python expression here.")))
 
@@ -805,7 +818,11 @@ class EntryLine(wx.TextCtrl, EntryLineEventMixin, GridCellEventMixin,
         post_command_event(self, self.GridActionTableSwitchMsg,
                            newtable=self.last_table)
         if is_gtk():
+            try:
                 wx.Yield()
+            except:
+                pass
+
         sel_start, sel_stop = self.last_selection
 
         shape = self.main_window.grid.code_array.shape
@@ -818,6 +835,11 @@ class EntryLine(wx.TextCtrl, EntryLineEventMixin, GridCellEventMixin,
         post_command_event(self, self.GridActionTableSwitchMsg,
                            newtable=current_table)
 
+    def OnLock(self, event):
+        """Event handler for locking the entry line"""
+
+        self.Enable(not event.lock)
+
     def OnText(self, event):
         """Text event method evals the cell and updates the grid"""
 
@@ -839,14 +861,98 @@ class EntryLine(wx.TextCtrl, EntryLineEventMixin, GridCellEventMixin,
             # Handle special keys
             keycode = event.GetKeyCode()
 
-            if keycode == 13:
-                # <Enter> pressed --> Focus on grid
+            if keycode == 13 and not self.GetStringSelection():
+                # <Enter> pressed and no selection --> Focus on grid
                 self.main_window.grid.SetFocus()
 
                 # Ignore <Ctrl> + <Enter> and Quote content
                 if event.ControlDown():
                     self.SetValue('"' + self.GetValue() + '"')
 
+                # Do not process <Enter>
+                return
+
+            elif keycode == 13 and self.GetStringSelection():
+                # <Enter> pressed and selection
+                # --> Place cursor at end of selection and clear selection
+                selection_start, selection_stop = self.Selection
+                self.SetSelection(selection_stop, selection_stop)
+
+                # Do not process <Enter>
+                return
+
+            elif keycode == 9 and jedi is None:
+                # Ignore the <Tab>
+                return
+
+            elif keycode == 9 and jedi is not None:
+                #  If auto completion library jedi is present
+                # <Tab> pressed --> show docstring tooltip
+
+                tiptext = ""
+
+                code = "".join(self.GetValue().split("\n"))
+                position = self.GetInsertionPoint()
+
+                # Get the docstring
+                code_array = self.parent.parent.parent.grid.code_array
+                env = code_array.get_globals()
+                try:
+                    script = jedi.Interpreter(code, [env], line=1,
+                                              column=position)
+                except ValueError:
+                    # Jedi has thrown an error
+                    event.Skip()
+                    return
+
+                completions = script.complete()
+                completes = [completion.complete for completion in completions]
+                complete = common_start(completes)
+                if complete:
+                    # There is a non-empty completion
+                    insertion_point = self.GetInsertionPoint()
+                    self.write(complete)
+                    if len(completes) > 1:
+                        self.SetSelection(insertion_point,
+                                          insertion_point + len(complete))
+
+                words = [completion.word for completion in completions]
+
+                docs = []
+                for completion in completions:
+                    doc = completion.docstring(fast=False)
+                    if not doc:
+                        # Is the completion part of a module?
+                        code_segment = \
+                            code[:position+1].split()[-1]
+                        module_name = code_segment.rsplit(".", 1)[0]
+                        try:
+                            module = env[module_name]
+                            doc = getattr(module, completion.name).__doc__
+                        except (KeyError, AttributeError):
+                            pass
+
+                    if not doc:
+                        name = completion.name
+                        try:
+                            # Is the completion a builtin?
+                            doc = getattr(__builtin__, name).__doc__
+                        except AttributeError:
+                            pass
+                    docs.append(doc)
+
+                try:
+                    dws = [": ".join([w, d]) for w, d in zip(words, docs)]
+
+                    tiptext = "\n \n".join(dws)
+                except TypeError:
+                    pass
+
+                # Cut tiptext length because Tooltip fails for long strings
+
+                self.SetToolTip(wx.ToolTip(tiptext[:MAX_TOOLTIP_LENGTH]))
+
+                # Do not process <Tab>
                 return
 
         event.Skip()
@@ -857,7 +963,13 @@ class EntryLine(wx.TextCtrl, EntryLineEventMixin, GridCellEventMixin,
         if hasattr(event, 'updated_cell'):
             # Event posted by cell edit widget.  Even more up to date
             #  than the current cell's contents
-            self.SetValue(event.updated_cell)
+            try:
+                self.SetValue(event.updated_cell)
+
+            except TypeError:
+                # None instead of string present
+                pass
+
         else:
             current_cell = self.main_window.grid.actions.cursor
             current_cell_code = self.main_window.grid.code_array(current_cell)
@@ -1004,7 +1116,11 @@ class TableChoiceIntCtrl(IntCtrl, GridEventMixin, GridActionEventMixin):
             post_command_event(self, self.GridActionTableSwitchMsg,
                                newtable=event.GetValue())
             if is_gtk():
-                wx.Yield()
+                try:
+                    wx.Yield()
+                except:
+                    pass
+
             self.switching = False
 
     def OnMouseWheel(self, event):
@@ -1039,4 +1155,4 @@ class TableChoiceIntCtrl(IntCtrl, GridEventMixin, GridActionEventMixin):
 
         event.Skip()
 
-# end of class TableChoiceIntCtrl
\ No newline at end of file
+# end of class TableChoiceIntCtrl
