@@ -65,6 +65,7 @@ class GtkArtProvider(wx.ArtProvider):
             "AlignCenter": action_path + "format-text-aligncenter.png",
             "AlignBottom": action_path + "format-text-alignbottom.png",
             "Freeze": action_path + "frozen_small.png",
+            "Lock": action_path + "lock.png",
             "Merge": action_path + "format-merge-table-cells.png",
             "AllBorders": toggle_path + "border_all.xpm",
             "LeftBorders": toggle_path + "border_left.xpm",
@@ -89,6 +90,8 @@ class GtkArtProvider(wx.ArtProvider):
             "contour": action_path + "chart_contour.png",  # matplotlib
             "Sankey": action_path + "chart_sankey.png",  # matplotlib
             "safe_mode": icon_path + "status/dialog-warning.png",
+            "SortAscending": action_path + "edit-sort-ascending.png",
+            "SortDescending": action_path + "edit-sort-descending.png",
         }
 
     def get_paths(self, theme, icon_size):
