@@ -106,6 +106,7 @@ class CellAttributes(list):
         "textcolor": get_color(config["text_color"]).GetRGB(),
         "underline": False,
         "strikethrough": False,
+        "locked": False,
         "angle": 0.0,
         "column-width": 150,
         "row-height": 26,
@@ -1117,10 +1118,16 @@ class CodeArray(DataArray):
     def _eval_cell(self, key, code):
         """Evaluates one cell and returns its result"""
 
+        # Flatten helper function
+        def nn(val):
+            """Returns flat numpy arraz without None values"""
+
+            return numpy.array(filter(None, val.flat))
+
         # Set up environment for evaluation
 
         env_dict = {'X': key[0], 'Y': key[1], 'Z': key[2], 'bz2': bz2,
-                    'base64': base64, 'charts': charts,
+                    'base64': base64, 'charts': charts, 'nn': nn,
                     'R': key[0], 'C': key[1], 'T': key[2], 'S': self}
         env = self._get_updated_environment(env_dict=env_dict)
 
@@ -1257,6 +1264,11 @@ class CodeArray(DataArray):
             if key not in base_keys:
                 globals().pop(key)
 
+    def get_globals(self):
+        """Returns globals dict"""
+
+        return globals()
+
     def execute_macros(self):
         """Executes all macros and returns result string
 
@@ -1437,8 +1449,13 @@ class CodeArray(DataArray):
         reverse = "UP" in flags
 
         for key in self._sorted_keys(self.keys(), startkey, reverse=reverse):
-            if is_matching(key, find_string, flags):
-                return key
+            try:
+                if is_matching(key, find_string, flags):
+                    return key
+
+            except Exception:
+                # re errors are cryptical: sre_constants,...
+                pass
 
     def handler(self, signum, frame):
         raise RuntimeError("Timeout after {} s.".format(config["timeout"]))
